@@ -11,8 +11,9 @@ if TYPE_CHECKING:  # Only import for type checking (is False at runtime).
 
 
 class Block:
-    def __init__(self):
+    def __init__(self, css=None):
         self._id = Context.id
+        self.css = css
         Context.id += 1
         if Context.block is not None:
             Context.block.children.append(self)
